# Nbcheckmate

Nb checkmate is your fellow library that allow you to test functions and variables inside of a notebook. 

## Installation

To install this package, you can use pip:

```
pip install nbcheckmate
```

## Usage

To use this package, you can import it in your Python code:

```python
import my_python_package

```

TODO : Add more documentation
